@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2017 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2018 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2018 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -92,26 +92,34 @@ class Appointment(ModelSQL, ModelView):
     # Create the QR code
 
         appointment_healthprof = ''
-        appointment_speciality = ''
+        appointment_patient = ''
+        patient_puid = ''
+        appointment_specialty = ''
+        appointment_date = ''
+        appointment = ''
         
-        appointment = self.name or ''
+        if (self.name):
+            appointment = self.name
 
         if (self.healthprof):
             appointment_healthprof = str(self.healthprof.rec_name) or ''
 
-        appointment_patient = self.patient.rec_name or ''
-
-        appointment_date = str(self.appointment_date) or ''
+        if (self.patient):
+            appointment_patient = self.patient.rec_name or ''
+            patient_puid = self.patient.puid
+            
+        if (self.appointment_date):
+            appointment_date = str(self.appointment_date)
 
         if (self.speciality):
-            appointment_speciality = str(self.speciality.rec_name) or ''
+            appointment_specialty = str(self.speciality.rec_name) or ''
 
         qr_string = 'ID: ' + appointment \
             + '\nName: ' + appointment_patient \
-            + '\nPUID: ' + appointment_patient.ref \
-            + '\nSpecialty: ' + appointment_speciality \
-            + '\nhealth Prof: ' + appointment_healthprof \
-            + '\nDate: ' + appointment_date 
+            + '\nPUID: ' + patient_puid \
+            + '\nSpecialty: ' + appointment_specialty \
+            + '\nhealth Prof: ' + appointment_healthprof or ''\
+            + '\nDate: ' + appointment_date or ''
         
         qr_image = qrcode.make(qr_string)
          
