@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2017 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2018 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2018 GNU Solidario <health@gnusolidario.org>
 #
 #    Copyright (C) 2011  Adrián Bernardi, Mario Puntin (health_invoice)
 #
@@ -22,26 +22,82 @@
 #
 ##############################################################################
 import datetime
-from trytond.model import ModelView, ModelSQL, fields, ModelSingleton, Unique
+from trytond.model import ModelView, ModelSQL, fields, ModelSingleton, \
+    Unique, ValueMixin
 from trytond.transaction import Transaction
 from trytond.pyson import Eval, Equal
 from trytond.pool import Pool
+from trytond import backend
+from trytond.tools.multivalue import migrate_property
 
 
-__all__ = ['GnuHealthSequences', 'HealthService', 'HealthServiceLine',
-    'PatientPrescriptionOrder']
+__all__ = ['GnuHealthSequences', 'GnuHealthSequenceSetup',
+    'HealthService', 'HealthServiceLine', 'PatientPrescriptionOrder']
 
+sequences = ['health_service_sequence']
 
 class GnuHealthSequences(ModelSingleton, ModelSQL, ModelView):
     "Standard Sequences for GNU Health"
     __name__ = "gnuhealth.sequences"
 
-    health_service_sequence = fields.Property(fields.Many2One('ir.sequence',
+    health_service_sequence = fields.MultiValue(fields.Many2One('ir.sequence',
         'Health Service Sequence', domain=[
             ('code', '=', 'gnuhealth.health_service')
         ], required=True))
 
 
+    @classmethod
+    def multivalue_model(cls, field):
+        pool = Pool()
+
+        if field in sequences:
+            return pool.get('gnuhealth.sequence.setup')
+        return super(GnuHealthSequences, cls).multivalue_model(field)
+
+    @classmethod
+    def default_health_service_sequence(cls):
+        return cls.multivalue_model(
+            'health_service_sequence').default_health_service_sequence()
+
+
+# SEQUENCE SETUP
+class GnuHealthSequenceSetup(ModelSQL, ValueMixin):
+    'GNU Health Sequences Setup'
+    __name__ = 'gnuhealth.sequence.setup'
+
+    health_service_sequence = fields.Many2One('ir.sequence', 
+        'Health Service Sequence', required=True,
+        domain=[('code', '=', 'gnuhealth.health_service')])
+
+  
+    @classmethod
+    def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
+        exist = TableHandler.table_exist(cls._table)
+
+        super(GnuHealthSequenceSetup, cls).__register__(module_name)
+
+        if not exist:
+            cls._migrate_MultiValue([], [], [])
+
+    @classmethod
+    def _migrate_property(cls, field_names, value_names, fields):
+        field_names.extend(sequences)
+        value_names.extend(sequences)
+        migrate_property(
+            'gnuhealth.sequences', field_names, cls, value_names,
+            fields=fields)
+
+    @classmethod
+    def default_health_service_sequence(cls):
+        pool = Pool()
+        ModelData = pool.get('ir.model.data')
+        return ModelData.get_id(
+            'health_services', 'seq_gnuhealth_health_service')
+    
+# END SEQUENCE SETUP , MIGRATION FROM FIELDS.MultiValue
+
+
 class HealthService(ModelSQL, ModelView):
     'Health Service'
     __name__ = 'gnuhealth.health_service'
@@ -139,6 +195,10 @@ class HealthServiceLine(ModelSQL, ModelView):
     def default_qty():
         return 1
 
+    @staticmethod
+    def default_to_invoice():
+        return True
+
     @fields.depends('product', 'desc')
     def on_change_product(self, name=None):
         if self.product:
